import * as tslib_1 from "tslib";
import * as React from 'react';
import { render } from 'react-dom';
import * as classNames from 'classnames';
import Transitions from '../Transitions';
import Icon from '../Icon';
var config = {
    top: 24,
    duration: 3000,
};
var Slide = Transitions.Slide;
var Message = /** @class */ (function (_super) {
    tslib_1.__extends(Message, _super);
    function Message() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Message.prototype.render = function () {
        var _a = this.props, className = _a.className, _b = _a.visible, visible = _b === void 0 ? true : _b, content = _a.content, type = _a.type, icon = _a.icon;
        var preCls = 'yoshino-message';
        var clsName = classNames(preCls, className, preCls + "-" + type);
        var defaultIcon = {
            success: 'md-checkmark-circle',
            info: 'md-information-circle',
            warning: 'md-alert',
            error: 'md-close-circle',
        };
        return (React.createElement(Slide, { active: visible, direction: 'top' },
            React.createElement("div", { className: clsName },
                React.createElement("div", { className: preCls + "-content" },
                    icon ? icon : React.createElement(Icon, { type: defaultIcon[type] }),
                    React.createElement("span", null, content)))));
    };
    return Message;
}(React.Component));
export { Message };
// 是否已将根节点容器挂载到body。
var flag = false;
var container = document.createElement('div');
container.setAttribute('class', 'yoshino-message-container');
container.style.top = config.top + '';
var messageStack = [];
var appendBody = function () {
    document.body.appendChild(container);
};
var updateContainer = function () {
    render((React.createElement(React.Fragment, null, messageStack.map(function (item) {
        var child = React.Children.only(item.ele);
        return React.cloneElement(child, {
            visible: item.visible,
            key: item.key,
        });
    }))), container);
    // 清除visible为false的
    var tempStack = messageStack.filter(function (item) { return item.visible; });
    messageStack.length = 0;
    messageStack.push.apply(messageStack, tempStack);
};
var renderMessages = function (props, type) {
    if (!flag) {
        appendBody();
        flag = true;
    }
    var key = props.key, duration = props.duration, onClose = props.onClose, otherProps = tslib_1.__rest(props, ["key", "duration", "onClose"]);
    var messageKey = key || (new Date().getDate() * Math.random());
    var timeoutId = window.setTimeout(function () {
        closeMessage(messageKey);
        if (onClose) {
            onClose();
        }
    }, props.duration || config.duration);
    var message = (React.createElement(Message, tslib_1.__assign({}, otherProps, { type: type })));
    messageStack.push({
        key: messageKey,
        timeoutId: timeoutId,
        visible: true,
        ele: message,
    });
    updateContainer();
    return messageKey;
};
var closeMessage = function (key) {
    for (var _i = 0, messageStack_1 = messageStack; _i < messageStack_1.length; _i++) {
        var item = messageStack_1[_i];
        if (item.key === key) {
            item.visible = false;
            updateContainer();
            return;
        }
    }
};
var setMessageConfig = function (props) {
    config = tslib_1.__assign({}, config, props);
};
var clearMessageStack = function () {
    messageStack.length = 0;
    updateContainer();
};
export default {
    config: setMessageConfig,
    success: function (props) {
        var param = typeof props === 'string' ? { content: props } : props;
        renderMessages(param, 'success');
    },
    info: function (props) {
        var param = typeof props === 'string' ? { content: props } : props;
        renderMessages(param, 'info');
    },
    warn: function (props) {
        var param = typeof props === 'string' ? { content: props } : props;
        renderMessages(param, 'warning');
    },
    error: function (props) {
        var param = typeof props === 'string' ? { content: props } : props;
        renderMessages(param, 'error');
    },
    close: closeMessage,
    destroy: clearMessageStack,
};
//# sourceMappingURL=Message.js.map