import * as tslib_1 from "tslib";
import { Component } from 'react';
import * as React from 'react';
import * as classNames from 'classnames';
import Icon from '../Icon';
/**
 * **组件中文名称**-组件描述。
 */
var Carousel = /** @class */ (function (_super) {
    tslib_1.__extends(Carousel, _super);
    function Carousel() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.preCls = 'yoshino-carousel';
        _this.jumpSwitch = true;
        _this.setContainerBound = function () {
            _this.setState({
                containerWidth: _this.refContainer.clientWidth,
                containerHeight: _this.refContainer.clientHeight,
            });
        };
        _this.state = {
            activeIndex: 1,
            containerWidth: 0,
            containerHeight: 0,
        };
        _this.setAutoplayInterval = function () {
            var _a = _this.props, interval = _a.interval, autoplay = _a.autoplay;
            if (!autoplay) {
                return;
            }
            _this.intervalHandle = setInterval(function () {
                _this.next();
            }, interval);
        };
        _this.getIndex = function (step) {
            var activeIndex = _this.state.activeIndex;
            var children = _this.props.children;
            var child = React.Children.toArray(children);
            var length = child.length + 2;
            if (step > 0) {
                return activeIndex + step >= length ? step - 1 : activeIndex + step;
            }
            if (step < 0) {
                return activeIndex + step < 0 ? length + step : activeIndex + step;
            }
            return activeIndex;
        };
        _this.goto = function (index) {
            if (!_this.jumpSwitch) {
                return;
            }
            _this.jumpSwitch = false;
            if (_this.intervalHandle) {
                clearInterval(_this.intervalHandle);
            }
            _this.setState({
                activeIndex: index,
            }, function () {
                _this.setAutoplayInterval();
            });
        };
        _this.next = function () {
            _this.goto(_this.getIndex(1));
        };
        _this.pre = function () {
            _this.goto(_this.getIndex(-1));
        };
        _this.renderChild = function () {
            var _a = _this.props, children = _a.children, vertical = _a.vertical;
            var child = React.Children.toArray(children);
            // 首尾各补一个child，保证循环滚动不间断
            child.unshift(child[child.length - 1]);
            child.push(child[1]);
            var width = _this.state.containerWidth;
            var height = _this.state.containerHeight;
            var childSum = child.length;
            var activeIndex = _this.state.activeIndex;
            var offset = (vertical ? height : width) * activeIndex;
            var listStyle = {
                width: vertical ? width : width * childSum,
                height: vertical ? height * childSum : height,
                transform: vertical ? "translateY(-" + offset + "px)" : "translateX(-" + offset + "px)",
            };
            if (_this.refList) {
                _this.refList.style.transition = 'all 0.3s cubic-bezier(0.645, 0.045, 0.355, 1)';
                _this.timeoutHandle = window.setTimeout(function () {
                    var first = 1;
                    var last = childSum - 2;
                    if (_this.timeoutHandle) {
                        clearTimeout(_this.timeoutHandle);
                    }
                    if (activeIndex === 0) {
                        _this.setState({ activeIndex: last });
                    }
                    if (activeIndex === childSum - 1) {
                        _this.setState({ activeIndex: first });
                    }
                    if (_this.refList) {
                        _this.refList.style.transition = null;
                    }
                    _this.jumpSwitch = true;
                }, 300);
            }
            return (React.createElement("div", { style: listStyle, className: _this.preCls + "-list", ref: function (v) {
                    if (v) {
                        _this.refList = v;
                    }
                } }, React.Children.map(child, function (item, index) {
                var itemStyle = {
                    width: width,
                    height: height,
                };
                return (React.createElement("div", { key: index, className: _this.preCls + "-child", style: itemStyle }, item));
            })));
        };
        _this.renderControl = function () {
            var _a = _this.props, vertical = _a.vertical, preIcon = _a.preIcon, nextIcon = _a.nextIcon;
            var preCls = _this.preCls;
            var preIconType = vertical ? 'ios-arrow-up' : 'ios-arrow-back';
            var nextIconType = vertical ? 'ios-arrow-down' : 'ios-arrow-forward';
            return (React.createElement(React.Fragment, null,
                React.createElement("div", { className: preCls + "-btn " + preCls + "-btn-pre", onClick: _this.pre }, preIcon || React.createElement(Icon, { type: preIconType })),
                React.createElement("div", { className: preCls + "-btn " + preCls + "-btn-next", onClick: _this.next }, nextIcon || React.createElement(Icon, { type: nextIconType }))));
        };
        _this.renderDots = function () {
            var preCls = _this.preCls;
            var children = _this.props.children;
            var activeIndex = _this.state.activeIndex;
            var child = React.Children.toArray(children);
            var renderDot = function () {
                var first = 1;
                var last = child.length + 1;
                var jsx = [];
                var _loop_1 = function (i) {
                    var _a;
                    var active = activeIndex;
                    if (activeIndex === 0) {
                        active = child.length;
                    }
                    if (activeIndex === last) {
                        active = 1;
                    }
                    var cls = classNames(preCls + "-dot", (_a = {},
                        _a[preCls + "-active-dot"] = active === i,
                        _a));
                    jsx.push(React.createElement("div", { className: cls, key: i, onClick: function () { return _this.goto(i); } }));
                };
                for (var i = first; i < last; i++) {
                    _loop_1(i);
                }
                return jsx;
            };
            return (React.createElement("div", { className: preCls + "-dots-box" }, renderDot()));
        };
        return _this;
    }
    Carousel.prototype.componentDidMount = function () {
        this.setAutoplayInterval();
        this.setContainerBound();
        document.body.addEventListener('resize', this.setContainerBound);
    };
    Carousel.prototype.componentWillMount = function () {
        document.body.removeEventListener('resize', this.setContainerBound);
    };
    Carousel.prototype.render = function () {
        var _this = this;
        var _a;
        var _b = this.props, className = _b.className, style = _b.style, autoplay = _b.autoplay, showControl = _b.showControl, shwoDots = _b.shwoDots, interval = _b.interval, vertical = _b.vertical, children = _b.children, preIcon = _b.preIcon, nextIcon = _b.nextIcon, otherProps = tslib_1.__rest(_b, ["className", "style", "autoplay", "showControl", "shwoDots", "interval", "vertical", "children", "preIcon", "nextIcon"]);
        var preCls = this.preCls;
        var clsName = classNames(preCls, className, (_a = {},
            _a[preCls + "-vertical"] = vertical,
            _a[preCls + "-horizontal"] = !vertical,
            _a));
        return (React.createElement("div", tslib_1.__assign({ className: clsName, style: style }, otherProps, { ref: function (v) {
                if (v) {
                    _this.refContainer = v;
                }
            } }),
            this.state.containerWidth ? this.renderChild() : null,
            showControl ? this.renderControl() : null,
            shwoDots ? this.renderDots() : null));
    };
    Carousel.defaultProps = {
        autoplay: true,
        interval: 3000,
        vertical: false,
        shwoDots: true,
        showControl: true,
    };
    return Carousel;
}(Component));
export { Carousel };
export default Carousel;
//# sourceMappingURL=Carousel.js.map