import * as tslib_1 from "tslib";
import Alert from '../Alert';
import * as React from 'react';
import { render } from 'react-dom';
import Transitions from '../Transitions';
var config = {
    vertical: 24,
    horizontal: 24,
    duration: 5000,
    placement: 'topRight',
};
// 是否已将根节点容器挂载到body。
var flag = false;
var container = document.createElement('div');
container.setAttribute('class', 'notification-container');
container.style.position = 'fixed';
container.style.zIndex = '999';
var notificationStack = [];
var resetPlacement = function () {
    container.style.left = null;
    container.style.right = null;
    container.style.top = null;
    container.style.bottom = null;
};
var setPlacement = function () {
    switch (config.placement) {
        case 'topLeft':
            container.style.top = config.vertical + "px";
            container.style.left = config.horizontal + "px";
            break;
        case 'topRight':
            container.style.top = config.vertical + "px";
            container.style.right = config.horizontal + "px";
            break;
        case 'bottomLeft':
            container.style.bottom = config.vertical + "px";
            container.style.left = config.horizontal + "px";
            break;
        case 'bottomRight':
            container.style.bottom = config.vertical + "px";
            container.style.right = config.horizontal + "px";
            break;
        default:
            break;
    }
};
var appendBody = function () {
    setPlacement();
    document.body.appendChild(container);
};
var updateContainer = function () {
    render((React.createElement(React.Fragment, null, notificationStack.map(function (item) { return React.cloneElement(item.element, {
        ref: function (v) {
            if (v) {
                item.ref = v;
            }
        },
        key: item.key,
    }); }))), container);
};
var renderNotifications = function (props, type, showIcon) {
    if (showIcon === void 0) { showIcon = true; }
    if (!flag) {
        appendBody();
        flag = true;
    }
    var key = props.key, duration = props.duration, message = props.message, icon = props.icon, otherProps = tslib_1.__rest(props, ["key", "duration", "message", "icon"]);
    var alertKey = key || (new Date().getTime() * Math.random());
    var timeoutId = window.setTimeout(function () {
        closeNotification(alertKey);
    }, props.duration || config.duration);
    var alertProps = tslib_1.__assign({ showIcon: showIcon || !!icon, icon: icon }, otherProps, { type: type, closable: true });
    var alert = (React.createElement(Alert, tslib_1.__assign({}, alertProps, { Animation: Transitions.Slide, animationProps: { direction: 'right' } }), message || null));
    notificationStack.push({
        key: alertKey,
        timeoutId: timeoutId,
        element: alert,
    });
    updateContainer();
    return alertKey;
};
var closeNotification = function (key) {
    var _loop_1 = function (notification) {
        var item = notification;
        if (item.key === key) {
            var ref = item.ref;
            ref.closeAlert();
            setTimeout(function () {
                notificationStack.splice(notificationStack.indexOf(item), 1);
                updateContainer();
            }, Alert.duration);
            return "break";
        }
    };
    for (var _i = 0, notificationStack_1 = notificationStack; _i < notificationStack_1.length; _i++) {
        var notification = notificationStack_1[_i];
        var state_1 = _loop_1(notification);
        if (state_1 === "break")
            break;
    }
};
var setNotificationConfig = function (props) {
    config = tslib_1.__assign({}, config, props);
    if (props.placement) {
        resetPlacement();
        setPlacement();
    }
};
var clearNotificationStack = function () {
    notificationStack.length = 0;
    updateContainer();
};
export default {
    config: setNotificationConfig,
    open: function (props) { return renderNotifications(props, 'normal', false); },
    success: function (props) { return renderNotifications(props, 'success'); },
    info: function (props) { return renderNotifications(props, 'info'); },
    warn: function (props) { return renderNotifications(props, 'warning'); },
    error: function (props) { return renderNotifications(props, 'error'); },
    close: closeNotification,
    destroy: clearNotificationStack,
};
//# sourceMappingURL=Notification.js.map