import { Component, ReactNode } from 'react';
import * as React from 'react';
import { IBaseComponent } from '../template/component';
export interface IPopProps extends IBaseComponent {
    /**
     * 气泡框位置
     */
    placement?: 'top' | 'left' | 'right' | 'bottom' | 'topLeft' | 'topRight' | 'bottomLeft' | 'bottomRight' | 'leftTop' | 'leftBottom' | 'rightTop' | 'rightBottom';
    /**
     * 鼠标移入后延时多少才显示 Pop， 单位: ms
     */
    mouseEnterDelay?: number;
    /**
     * 鼠标移出后延时多少才隐藏 Pop，单位：ms
     */
    mouseLeaveDelay?: number;
    /**
     * 卡片类名
     */
    overlayClassName?: string;
    /**
     * 卡片样式
     */
    overlayStyle?: React.CSSProperties;
    /**
     * 触发行为 - hoverClick是指点击蒙层后关闭
     */
    trigger?: 'hover' | 'focus' | 'click' | 'hoverClick';
    /**
     * 受控-是否可见
     */
    visible?: boolean;
    /**
     * 是否可见
     */
    defaultVisible?: boolean;
    /**
     *  变化回调
     */
    onChange?: (visible: boolean) => void;
    /**
     * 气泡框内容
     */
    content?: string | ReactNode;
    /**
     * 进入时才渲染
     */
    mountOnEnter?: boolean;
    /**
     * 宽度继承
     */
    inheritWidth?: boolean;
    /**
     * 继承宽度为最小宽度
     */
    isMinWidth?: boolean;
    /**
     * 变化回调 - 延迟前
     */
    onChangeBefore?: (visible: boolean) => void;
    /**
     * trigger为focus模式时，如果开启该属性，点击浮层元素一次就触发关闭
     */
    focusOnce?: boolean;
}
export interface IPopState {
    visible: boolean;
}
/**
 * **组件中文名称**-组件描述。
 */
export declare class Pop extends Component<IPopProps, IPopState> {
    refChildren: HTMLElement;
    timeoutHandle: number;
    timueoutFoucs?: number;
    animateTimeHandle: number[];
    popId: string;
    static defaultProps: {
        placement: string;
        mouseEnterDelay: number;
        mouseLeaveDelay: number;
        trigger: string;
        overlayClassName: string;
        overlayStyle: {};
        defaultVisible: boolean;
        mountOnEnter: boolean;
        inheritWidth: boolean;
        isMinWidth: boolean;
        focusOnce: boolean;
    };
    state: {
        visible: boolean;
    };
    renderPop: () => JSX.Element | null;
    resetPopPostion: () => void;
    getVisible: () => boolean;
    onChangeTrigger: (visible: boolean) => void;
    toggleVisible: (visible: boolean) => void;
    getTargetTriggerAction: () => {
        onMouseEnter: any;
        onMouseLeave: any;
    } | {
        onMouseEnter: any;
        onMouseLeave: any;
    } | {
        onFocus: any;
        onBlur: any;
    } | {
        onClick: any;
    };
    getConentTriggerAction: () => {
        onMouseEnter: any;
        onMouseLeave: any;
    } | {
        onFocus: any;
        onBlur: any;
        onClick: () => void;
    } | {} | {
        onMouseEnter: any;
        onMouseLeave: any;
        onClick: any;
    };
    render(): React.ReactElement<any>;
}
export default Pop;
