import * as tslib_1 from "tslib";
import { Component } from 'react';
import * as React from 'react';
import * as classNames from 'classnames';
/**
 * **滑动输入条**-用于拖动选取当前值
 */
var Slider = /** @class */ (function (_super) {
    tslib_1.__extends(Slider, _super);
    function Slider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.moving = false; // 当前是否处于拖动状态
        _this.state = {
            value: _this.props.defaultValue,
        };
        _this.getValue = function () {
            var value = _this.props.value;
            return value !== undefined ? value : _this.state.value;
        };
        _this.getStepPercent = function () {
            var _a = _this.props, max = _a.max, min = _a.min, step = _a.step;
            var range = max - min;
            var percent = step / range;
            return +percent.toFixed(4);
        };
        _this.getPercent = function () {
            var _a = _this.props, max = _a.max, min = _a.min;
            var value = _this.getValue();
            var range = max - min;
            var percent = (value - min) / range;
            return +percent.toFixed(4);
        };
        _this.onSliderClick = function (e) {
            var _a = _this.props, max = _a.max, min = _a.min;
            var slider = _this.refSlider;
            var sliderRect = slider.getBoundingClientRect();
            var sliderWidth = sliderRect.width; // 滑动条宽度
            var left = e.clientX - (sliderRect.x || sliderRect.left); // 点击位置相对滑动条偏移量
            var newPercent = +(left / sliderWidth).toFixed(4);
            var oldPercent = _this.getPercent();
            var stepPercent = _this.getStepPercent();
            var change = newPercent - oldPercent;
            var times = Math.abs(Math.round(change / stepPercent));
            if (times !== 0) {
                var changePercent = times * stepPercent;
                var percent = change > 0 ? oldPercent + changePercent : oldPercent - changePercent;
                _this.onChangeTrigger(min + Math.round((max - min) * percent));
            }
            _this.moving = false;
        };
        _this.onSliderMouseDown = function () {
            var _a = _this.props, max = _a.max, min = _a.min;
            var slider = _this.refSlider;
            var sliderRect = slider.getBoundingClientRect();
            var sliderWidth = sliderRect.width; // 滑动条宽度
            var bodyMouseMove = function (e) {
                var left = e.clientX - (sliderRect.x || sliderRect.left); // 点击位置相对滑动条偏移量
                // 当前偏移量处于滑动条外 不进行value刷新
                if (left < 0 || left > sliderWidth) {
                    return;
                }
                var newPercent = +(left / sliderWidth).toFixed(4);
                var oldPercent = _this.getPercent();
                var stepPercent = _this.getStepPercent();
                var change = newPercent - oldPercent;
                var times = Math.abs(Math.round(change / stepPercent));
                if (times !== 0) {
                    var changePercent = times * stepPercent;
                    var percent = change > 0 ? oldPercent + changePercent : oldPercent - changePercent;
                    _this.onChangeTrigger(min + Math.round((max - min) * percent));
                }
                // this.onChangeTrigger(min + Math.round((max - min) * percent));
            };
            var bodyMouseUp = function () {
                document.body.removeEventListener('mousemove', bodyMouseMove);
                document.body.removeEventListener('mouseup', bodyMouseUp);
            };
            document.body.addEventListener('mousemove', bodyMouseMove);
            document.body.addEventListener('mouseup', bodyMouseUp);
        };
        _this.onChangeTrigger = function (value) {
            // 节流 - 当value发生变化时才刷新
            if (value === _this.getValue()) {
                return;
            }
            var _a = _this.props, onChange = _a.onChange, disabled = _a.disabled;
            if (disabled) {
                return;
            }
            _this.setState({
                value: value,
            });
            if (onChange) {
                onChange(value);
            }
        };
        return _this;
    }
    Slider.prototype.render = function () {
        var _this = this;
        var _a;
        var _b = this.props, className = _b.className, style = _b.style, children = _b.children, defaultValue = _b.defaultValue, disabled = _b.disabled, onChange = _b.onChange, step = _b.step, otherProps = tslib_1.__rest(_b, ["className", "style", "children", "defaultValue", "disabled", "onChange", "step"]);
        var preCls = 'yoshino-slider';
        var clsName = classNames(preCls, (_a = {}, _a[preCls + "-disabled"] = disabled, _a), className);
        var barStyle = { width: this.getPercent() * 100 + "%" };
        return (React.createElement("div", tslib_1.__assign({ className: clsName, style: style, onClick: this.onSliderClick, onMouseDown: this.onSliderMouseDown }, otherProps, { ref: function (v) {
                if (v) {
                    _this.refSlider = v;
                }
            } }),
            React.createElement("div", { className: preCls + "-process" }),
            React.createElement("div", { className: preCls + "-bar", style: barStyle })));
    };
    Slider.defaultProps = {
        defaultValue: 0,
        max: 100,
        min: 0,
        disabled: false,
        step: 1,
    };
    return Slider;
}(Component));
export { Slider };
export default Slider;
//# sourceMappingURL=Slider.js.map