import * as tslib_1 from "tslib";
import { Component } from 'react';
import * as React from 'react';
import * as classNames from 'classnames';
import Pane from './Pane';
/**
 * **组件中文名称**-组件描述。
 */
var Tabs = /** @class */ (function (_super) {
    tslib_1.__extends(Tabs, _super);
    function Tabs() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.preCls = 'yoshino-tabs';
        _this.state = {
            activeIndex: -1,
            activeKey: _this.props.defaultActivetKey,
            ink: {
                height: 0,
                width: 0,
                left: 0,
                top: 0,
            },
        };
        _this.resetInkBarStyle = function (e) {
            var height = e.offsetHeight;
            var width = e.offsetWidth;
            var left = e.offsetLeft;
            var top = e.offsetTop;
            _this.setState({ ink: { height: height, width: width, left: left, top: top } });
        };
        _this.getActiveKey = function () {
            var activeKey = _this.props.activeKey;
            return activeKey !== undefined ? activeKey : _this.state.activeKey;
        };
        _this.onChange = function (key) {
            var onChange = _this.props.onChange;
            if (_this.getActiveKey() === key) {
                return;
            }
            if (onChange) {
                onChange(key);
            }
            _this.setState({
                activeKey: key,
            });
        };
        _this.renderTabPane = function () {
            var _a = _this.props, children = _a.children, tabPosition = _a.tabPosition, onTabClick = _a.onTabClick, tabBarGutter = _a.tabBarGutter, type = _a.type;
            var child = React.Children.toArray(children);
            var _b = _this.state.ink, width = _b.width, height = _b.height, left = _b.left, top = _b.top;
            var vertical = ['left', 'right'].indexOf(tabPosition) !== -1;
            var transform = vertical ? "translate3d(0, " + top + "px, 0)" : "translate3d(" + left + "px, 0, 0)";
            var inkBarStyle = Object.assign({ transform: transform }, vertical ? { height: height } : { width: width });
            var isLine = type === 'line';
            // clear
            _this.refActiveTabPaneArr = [];
            return (React.createElement("div", { className: _this.preCls + "-nav-wrap" },
                React.createElement("div", { className: _this.preCls + "-nav-scroll" }, React.Children.map(child, function (ele, index) {
                    var _a;
                    var _b = ele.props, name = _b.name, disabled = _b.disabled;
                    var active = _this.getActiveKey() === name;
                    var preCls = _this.preCls + "-tab";
                    var cls = classNames(preCls, (_a = {},
                        _a[preCls + "-active"] = active,
                        _a[preCls + "-disabled"] = disabled,
                        _a));
                    var style = tabBarGutter ? vertical ? {
                        marginBottom: tabBarGutter,
                    } : { marginRight: tabBarGutter } : {};
                    return (React.createElement("div", { className: cls, style: style, key: index, onClick: function (e) {
                            if (disabled) {
                                return;
                            }
                            if (onTabClick) {
                                onTabClick(ele.props.name);
                            }
                            // 当type === 'line' 渲染ink bar style
                            if (isLine) {
                                _this.resetInkBarStyle(e.target);
                            }
                            _this.setState({ activeIndex: index });
                            _this.onChange(name);
                        }, ref: function (v) {
                            if (v) {
                                _this.refActiveTabPaneArr.push(v);
                            }
                        } }, ele.props.name));
                })),
                isLine ? React.createElement("div", { className: _this.preCls + "-ink-bar", style: inkBarStyle }) : null));
        };
        _this.renderTabPaneContent = function () {
            var children = _this.props.children;
            var child = React.Children.toArray(children);
            var preCls = _this.preCls + "-pane";
            return (React.createElement(React.Fragment, null, React.Children.map(child, function (ele) {
                var _a;
                var name = ele.props.name;
                var active = _this.getActiveKey() === name;
                var className = classNames(ele.props.className, (_a = {},
                    _a[preCls + "-active"] = active,
                    _a[preCls + "-inactive"] = !active,
                    _a));
                return React.cloneElement(ele, {
                    className: className,
                    active: ".$" + _this.getActiveKey() === ele.key,
                    style: tslib_1.__assign({}, ele.props.style)
                });
            })));
        };
        return _this;
    }
    Tabs.prototype.componentDidMount = function () {
        var _this = this;
        // 获取activeIndex
        var children = this.props.children;
        var activeKey = this.getActiveKey();
        var child = React.Children.toArray(children);
        React.Children.forEach(child, function (ele, index) {
            if (ele.props.name === activeKey) {
                _this.setState({
                    activeIndex: index
                }, function () {
                    // 设置ink bar偏移
                    _this.resetInkBarStyle(_this.refActiveTabPaneArr[index]);
                });
            }
        });
    };
    Tabs.prototype.componentDidUpdate = function (preProps) {
        var _this = this;
        if (preProps.tabPosition !== this.props.tabPosition || preProps.size !== this.props.size) {
            // 当type !== 'line' 时无需渲染ink bar style
            if (this.props.type !== 'line') {
                return;
            }
            // 这里要等动画时间结束后才能拿到真实长宽
            var timeout = this.props.animated ? 300 + 1 : 0;
            setTimeout(function () {
                _this.resetInkBarStyle(_this.refActiveTabPaneArr[_this.state.activeIndex]);
            }, timeout);
        }
    };
    Tabs.prototype.render = function () {
        var _a;
        var _b = this.props, className = _b.className, style = _b.style, size = _b.size, animated = _b.animated, onChange = _b.onChange, type = _b.type, activeKey = _b.activeKey, defaultActivetKey = _b.defaultActivetKey, tabBarGutter = _b.tabBarGutter, children = _b.children, tabPosition = _b.tabPosition, otherProps = tslib_1.__rest(_b, ["className", "style", "size", "animated", "onChange", "type", "activeKey", "defaultActivetKey", "tabBarGutter", "children", "tabPosition"]);
        var preCls = this.preCls;
        var vertical = ['left', 'right'].indexOf(tabPosition) !== -1;
        var clsName = classNames(preCls, className, preCls + "-" + size, (_a = {},
            _a[preCls + "-animated"] = animated,
            _a[preCls + "-vertical"] = vertical,
            _a[preCls + "-horizontal"] = !vertical,
            _a[preCls + "-no-animated"] = !animated,
            _a[preCls + "-card"] = type === 'card',
            _a), preCls + "-" + tabPosition);
        var activeIndex = this.state.activeIndex;
        var contentStyle = !vertical ? {
            marginLeft: "-" + activeIndex * 100 + "%",
        } : { marginTop: "-" + activeIndex * 100 + "%" };
        return (React.createElement("div", tslib_1.__assign({ className: clsName, style: style }, otherProps),
            tabPosition !== 'bottom' ? this.renderTabPane() : null,
            activeIndex !== -1 ? (React.createElement("div", { className: preCls + "-content", style: contentStyle }, this.renderTabPaneContent())) : null,
            tabPosition === 'bottom' ? this.renderTabPane() : null));
    };
    Tabs.defaultProps = {
        size: 'default',
        tabPosition: 'top',
        animated: true,
        type: 'line',
    };
    Tabs.TabPane = Pane;
    return Tabs;
}(Component));
export { Tabs };
export default Tabs;
//# sourceMappingURL=Tabs.js.map